summary refs log tree commit diff
path: root/fs/cifs/dir.c
diff options
context:
space:
mode:
authorSteve French <sfrench@us.ibm.com>2005-07-14 18:25:12 -0500
committerSteve French <sfrench@us.ibm.com>2005-07-14 18:25:12 -0500
commitd7245c2ccf14cde2023273c1ec246732d96e2c27 (patch)
tree657d7b5c9431b6117659f9638f4121ac237d4c5f /fs/cifs/dir.c
parent4887c61811c2283162684d7f9075b7676ef6a9bf (diff)
downloadlinux-d7245c2ccf14cde2023273c1ec246732d96e2c27.tar.gz
[CIFS] Add compat with SFU (part 1)
This should help the case of creating fifos and other special files to
servers which do not support the Unix extensions.

Signed-off-by: Steve French (sfrench@us.ibm.com)

Thanks to Martin Koeppe for his suggestions and good analysis
Diffstat (limited to 'fs/cifs/dir.c')
-rw-r--r--fs/cifs/dir.c12
1 files changed, 11 insertions, 1 deletions
diff --git a/fs/cifs/dir.c b/fs/cifs/dir.c
index 9360d8fb9ef7..0d5e27fec92b 100644
--- a/fs/cifs/dir.c
+++ b/fs/cifs/dir.c
@@ -209,7 +209,7 @@ cifs_create(struct inode *inode, struct dentry *direntry, int mode,
 						CIFS_MOUNT_MAP_SPECIAL_CHR);
 			}
 		else {
 			/* BB implement via Windows security descriptors */
 			/* eg CIFSSMBWinSetPerms(xid,pTcon,full_path,mode,-1,-1,local_nls);*/
 			/* could set r/o dos attribute if mode & 0222 == 0 */
 		}
@@ -326,6 +326,16 @@ int cifs_mknod(struct inode *inode, struct dentry *direntry, int mode, dev_t dev
 			if(rc == 0)
 				d_instantiate(direntry, newinode);
 		}
+	} else {
+		if((cifs_sb->mnt_cifs_flags & CIFS_MOUNT_UNX_EMUL) && 
+			(special_file(mode))) {
+
+			cFYI(1,("sfu compat create special file"));
+			/*	Attributes = cpu_to_le32(ATTR_SYSTEM); 
+				rc = CIFSSMBOpen(xid, pTcon, full_path, disposition, ...); */
+
+			/* add code here to set EAs */
+		}
 	}
 
 	kfree(full_path);
@@ -209,7 +209,7 @@ cifs_create(struct inode *inode, struct dentry *direntry, int mode,
 			}
 		else {
-			/* BB implement via Windows security descriptors */
+			/* BB implement mode setting via Windows security descriptors */
 			/* eg CIFSSMBWinSetPerms(xid,pTcon,full_path,mode,-1,-1,local_nls);*/
 			/* could set r/o dos attribute if mode & 0222 == 0 */